| Title: | The Comrades Marathon 1921 to 2019 |
|---|---|
| Description: | Datasets related to the Comrades Marathon used in the book Antony Unwin (2024, ISBN:978-0367674007) "Getting (more out of) Graphics". The main dataset contains the times of every runner that finished in the time limit for each year the race was run. |
| Authors: | Antony Unwin [aut, cre, cph] |
| Maintainer: | Antony Unwin <[email protected]> |
| License: | GPL (>= 2) |
| Version: | 0.1.1 |
| Built: | 2026-05-24 09:21:54 UTC |
| Source: | https://github.com/cran/ComradesM |
Detailed individual results of the South African Comrades Marathon race
data(cmAll)data(cmAll)
A data frame with 445129 observations on the following 12 variables.
DirectionDirection of race, up (Durban to Pietermaritzburg) or down (Pietermaritzburg to Durban)
BibRace bib number
NameRunner's name
NationRunner's nationality
ClubRunner's club
TimeFinish time in HH:MM:SS
MedalMedal won
CategoryAge group
OA PlacePlace overall
Sex PlacePlacing within male or female
Cat PlacePlacing within age group
YearYear of race
This dataset and the datasets cmDist and cmE are all used in Chapter 21, "Over 90 years running 90 km"
https://www.kaggle.com/datasets/suugaku/comrades-marathon-results
data(cmAll, package="ComradesM") with(cmAll, table(Direction))data(cmAll, package="ComradesM") with(cmAll, table(Direction))
Distances run in the South African Comrades Marathon race since 1970
data(cmDist)data(cmDist)
A data frame with 50 observations on the following 3 variables.
YearYear of race
DirectionDirection of race, up (Durban to Pietermaritzburg) or down (Pietermaritzburg to Durban)
DistanceRace distance in kms
This dataset and the datasets cmAll and cmE are all used in Chapter 21, "Over 90 years running 90 km"
data(cmDist, package="ComradesM") with(cmDist, summary(Distance))data(cmDist, package="ComradesM") with(cmDist, summary(Distance))
Elevations along the planned Comrades Marathon route from Pietermaritzburg to Durban for 2020
data(cmE)data(cmE)
A data frame with 109 observations on the following 3 variables.
DistanceDistance from Pietermaritzburg in kms
ElevationHeight above sea level in metres
NameName of point, if known
This dataset and the datasets cmAll and cmDist are all used in Chapter 21, "Over 90 years running 90 km"
Based on information provided by the Comrades Marathon Association.
data(cmE, package="ComradesM") with(cmE, summary(Elevation))data(cmE, package="ComradesM") with(cmE, summary(Elevation))
The runners' times of the Comrades Marathon in South Africa for the years 1921 to 2019 together with race distances over the years and route elevation data.
Most of the datasets analysed in the book are available in GmooG and other R packages.
Antony Unwin [email protected]